<?php
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * @since 4.4
 * Default templates list
 */

/** Landing page template */
$data = array();
$data['name'] = esc_html__( 'Landing Page', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/3"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/1"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/3"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Call to Action Page template */
$data = array();
$data['name'] = esc_html__( 'Call to Action Page', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width=""][vc_column width="1/1"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_separator color="grey" align="align_center" style="" border_width="" el_width=""][/vc_column][/vc_row][vc_row full_width=""][vc_column width="1/2"][vc_single_image image="" alignment="" style="" border_color="grey" img_link_large="" img_link_target="_self" css_animation=""][/vc_column][vc_column width="1/2"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="flat" shape="rounded" color="blue" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column][/vc_row][vc_row full_width=""][vc_column width="1/2"][vc_single_image image="" alignment="" style="" border_color="grey" img_link_large="" img_link_target="_self" css_animation=""][/vc_column][vc_column width="1/2"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="flat" shape="rounded" color="blue" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" css_animation="" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Feature List template */
$data = array();
$data['name'] = esc_html__( 'Feature List', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/1"][vc_single_image border_color="grey" img_link_target="_self" alignment="center"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/3"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Description Page template */
$data = array();
$data['name'] = esc_html__( 'Description Page', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/1"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/2"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/2"][vc_single_image border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Service List template */
$data = array();
$data['name'] = esc_html__( 'Service List', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/2"][vc_single_image border_color="grey" img_link_target="_self"][/vc_column][vc_column width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/2"][vc_single_image border_color="grey" img_link_target="_self"][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_single_image border_color="grey" img_link_target="_self"][/vc_column][vc_column width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/2"][vc_single_image border_color="grey" img_link_target="_self"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Product Page template */
$data = array();
$data['name'] = esc_html__( 'Product Page', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width=""][vc_column width="1/1"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_separator color="grey" align="align_center" style="" border_width="" el_width=""][vc_single_image image="" alignment="" style="" border_color="grey" img_link_large="" img_link_target="_self" css_animation=""][vc_separator color="grey" align="align_center" style="" border_width="" el_width=""][/vc_column][/vc_row][vc_row full_width=""][vc_column width="1/2"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="flat" shape="rounded" color="blue" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column][vc_column width="1/2"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="flat" shape="rounded" color="blue" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" css_animation="" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );// New templates. Since 4.4
/** FAQ section */
$data = array();
$data['name'] = esc_html__( 'FAQ section', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/1"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/1"][vc_separator color="grey"][/vc_column][/vc_row][vc_row][vc_column width="1/1"][vc_toggle title="First question" open="true"]Toggle content goes here, click edit button to change this text.[/vc_toggle][vc_toggle title="Second question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][vc_toggle title="Third question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][vc_toggle title="Fourth question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][vc_toggle title="Fifth question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** About section */
$data = array();
$data['name'] = esc_html__( 'About section', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="2/3"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_row_inner][vc_column_inner width="1/1"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][vc_separator color="grey"][vc_row_inner][vc_column_inner width="1/1"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** About section */
$data = array();
$data['name'] = esc_html__( 'About with features', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/1"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/3"][vc_single_image alignment="center" border_color="grey" img_link_target="_self" style="vc_box_outline"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image alignment="center" border_color="grey" img_link_target="_self" style="vc_box_outline"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image alignment="center" border_color="grey" img_link_target="_self" style="vc_box_outline"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/1"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Three image description */
$data = array();
$data['name'] = esc_html__( 'Three image description', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/1"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column][vc_column width="1/2"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column][/vc_row][vc_row][vc_column width="1/1"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** News list */
$data = array();
$data['name'] = esc_html__( 'News list', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width=""][vc_column width="1/2"][vc_single_image image="" alignment="" style="vc_box_outline" border_color="grey" img_link_large="" img_link_target="_self" css_animation=""][/vc_column][vc_column width="1/2"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="flat" shape="rounded" color="purple" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column][/vc_row][vc_row full_width=""][vc_column width="1/2"][vc_single_image image="" alignment="" style="vc_box_outline" border_color="grey" img_link_large="" img_link_target="_self" css_animation=""][/vc_column][vc_column width="1/2"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="flat" shape="rounded" color="purple" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" css_animation="" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column][/vc_row][vc_row full_width=""][vc_column width="1/2"][vc_single_image image="" alignment="" style="vc_box_outline" border_color="grey" img_link_large="" img_link_target="_self" css_animation=""][/vc_column][vc_column width="1/2"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="flat" shape="rounded" color="purple" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" css_animation="" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Product description */
$data = array();
$data['name'] = esc_html__( 'Product description', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/2"][vc_single_image style="vc_box_rounded"][/vc_column][vc_column width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/2"][/vc_column][vc_column width="1/2"][vc_tta_tabs][vc_tta_section title="Tab 1" tab_id="1441874172163-094e5af5-15d5"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_tta_section][vc_tta_section title="Tab 2" tab_id="1441874172283-f430400e-9d32"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_tta_section][/vc_tta_tabs][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Description with accordion */
$data = array();
$data['name'] = esc_html__( 'Description with accordion', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:center" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]
I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.
[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][vc_tta_accordion][vc_tta_section title="Section 1" tab_id="1441874023656-b1376fe8-b671"][vc_row_inner][vc_column_inner width="1/2"][vc_single_image style="vc_box_outline"][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_tta_section][vc_tta_section title="Section 2" tab_id="1441874023759-fa988392-b9ad"][vc_row_inner][vc_column_inner width="1/2"][vc_single_image style="vc_box_outline"][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_tta_section][/vc_tta_accordion][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Two column list */
$data = array();
$data['name'] = esc_html__( 'Two column list', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/2"][vc_row_inner][vc_column_inner width="1/2"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner width="1/2"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner width="1/2"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][vc_column width="1/2"][vc_row_inner][vc_column_inner width="1/2"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner width="1/2"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner width="1/2"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** About with tour section */
$data = array();
$data['name'] = esc_html__( 'About with tour section', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/2"][vc_custom_heading text="This is custom heading element with Google Fonts" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/2"][vc_tta_tour][vc_tta_section title="Section 1" tab_id="1441873848705-137dadc4-4794"][vc_row_inner][vc_column_inner][vc_single_image alignment="center" style="vc_box_border"][vc_column_text]
I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.
[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_tta_section][vc_tta_section title="Section 2" tab_id="1441873848772-340367cb-2989"][vc_row_inner][vc_column_inner][vc_single_image alignment="center" style="vc_box_border"][vc_column_text]
I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.
[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_tta_section][/vc_tta_tour][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Rounded image description */
$data = array();
$data['name'] = esc_html__( 'Rounded image description', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/1"][vc_single_image alignment="center" style="vc_box_circle" border_color="grey" img_link_target="_self"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_single_image alignment="center" style="vc_box_circle" border_color="grey" img_link_target="_self"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][vc_column width="1/2"][vc_single_image alignment="center" style="vc_box_circle" border_color="grey" img_link_target="_self"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/3"][vc_single_image alignment="center" style="vc_box_circle" border_color="grey" img_link_target="_self"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image alignment="center" style="vc_box_circle" border_color="grey" img_link_target="_self"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image alignment="center" style="vc_box_circle" border_color="grey" img_link_target="_self"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Description with success message */
$data = array();
$data['name'] = esc_html__( 'Description with success message', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/1"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_message color="alert-success" style="rounded"]I am message box. Click edit button to change this text.[/vc_message][vc_row_inner][vc_column_inner width="1/2"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_circle"][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Images with tab description */
$data = array();
$data['name'] = esc_html__( 'Images with tab description', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/3"][vc_single_image alignment="center" style="vc_box_rounded"][/vc_column][vc_column width="1/3"][vc_single_image alignment="center" style="vc_box_rounded"][/vc_column][vc_column width="1/3"][vc_single_image alignment="center" style="vc_box_rounded"][/vc_column][/vc_row][vc_row][vc_column][vc_text_separator title="Title goes here"][/vc_column][/vc_row][vc_row][vc_column][vc_tta_tabs][vc_tta_section title="Tab 1" tab_id="1441874105744-0aeac9cb-3a3a"][vc_row_inner][vc_column_inner width="1/2"][vc_video][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_tta_section][vc_tta_section title="Tab 2" tab_id="1441874105862-625e36ff-76a2"][vc_row_inner][vc_column_inner width="1/2"][vc_single_image style="vc_box_rounded"][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_tta_section][/vc_tta_tabs][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Square on background */
$data = array();
$data['name'] = esc_html__( 'Square on background', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="" css=".vc_custom_1411477992738{background-color: #cecece !important;}"][vc_column width="1/1"][vc_empty_space height="200px"][vc_row_inner][vc_column_inner el_class="" width="1/3"][/vc_column_inner][vc_column_inner el_class="" width="1/3" css=".vc_custom_1411468859742{background-color: #ffffff !important;}"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:center|color:%23222222" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][vc_cta h2="Hey! I am first heading line feel free to change me" h2_google_fonts="font_family:Abril%20Fatface%3Aregular|font_style:400%20regular%3A400%3Anormal" h4_google_fonts="font_family:Abril%20Fatface%3Aregular|font_style:400%20regular%3A400%3Anormal" txt_align="center" shape="rounded" style="classic" color="classic" add_button="bottom" btn_title="Try now" btn_style="flat" btn_shape="rounded" btn_color="juicy-pink" btn_size="md" btn_align="center" btn_i_align="left" btn_i_type="fontawesome" btn_i_icon_fontawesome="fas fa-adjust" btn_i_icon_openiconic="vc-oi vc-oi-dial" btn_i_icon_typicons="typcn typcn-adjust-brightness" btn_i_icon_entypo="entypo-icon entypo-icon-note" btn_i_icon_linecons="vc_li vc_li-heart" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" i_color="blue" i_background_color="grey" i_size="md" use_custom_fonts_h2="" use_custom_fonts_h4="" btn_button_block="" btn_add_icon="" btn_i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert" i_on_border=""]I am promo text. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_cta][/vc_column_inner][vc_column_inner el_class="" width="1/3"][/vc_column_inner][/vc_row_inner][vc_empty_space height="200px"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Product description with tabs */
$data = array();
$data['name'] = esc_html__( 'Product description with tabs', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/2"][vc_single_image style="vc_box_rounded"][/vc_column][vc_column width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][vc_tta_tabs][vc_tta_section title="Tab 1" tab_id="1441874218694-385c7ca7-4943"][vc_row_inner][vc_column_inner width="1/2"][vc_video][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_tta_section][vc_tta_section title="Tab 2" tab_id="1441874218832-398800e3-835e"][vc_row_inner][vc_column_inner width="1/2"][vc_single_image style="vc_box_rounded"][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_tta_section][/vc_tta_tabs][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Description with headings */
$data = array();
$data['name'] = esc_html__( 'Description with headings', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width=""][vc_column width="1/1"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:center" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][/vc_row][vc_row full_width=""][vc_column width="1/1"][vc_separator color="grey" align="align_center" style="dashed" border_width="" el_width=""][/vc_column][/vc_row][vc_row full_width=""][vc_column width="1/2"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h3|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="flat" shape="round" color="sandy-brown" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column][vc_column width="1/2"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h3|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]<p style="text-align: left;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][vc_btn title="Read more" style="flat" shape="round" color="sandy-brown" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" css_animation="" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Video description */
$data = array();
$data['name'] = esc_html__( 'Video with description', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/6"][/vc_column][vc_column width="4/6"][vc_video][/vc_column][vc_column width="1/6"][/vc_column][/vc_row][vc_row][vc_column width="1/1"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/1"][vc_separator color="grey" style="dotted"][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_row_inner][vc_column_inner width="1/2"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][vc_column width="1/2"][vc_row_inner][vc_column_inner width="1/2"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Description with buttons */
$data = array();
$data['name'] = esc_html__( 'Description with buttons', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width=""][vc_column width="1/1"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:center" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][/vc_row][vc_row full_width=""][vc_column width="1/2"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h3|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="3d" shape="rounded" color="chino" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column][vc_column width="1/2"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h3|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="3d" shape="rounded" color="chino" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" css_animation="" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column][/vc_row][vc_row full_width=""][vc_column width="1/3"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h4|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="3d" shape="rounded" color="chino" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" css_animation="" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column][vc_column width="1/3"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h4|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="3d" shape="rounded" color="chino" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" css_animation="" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column][vc_column width="1/3"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h4|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="3d" shape="rounded" color="chino" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" css_animation="" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Map and Contacts */
$data = array();
$data['name'] = esc_html__( 'Map and Contacts', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/1"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:center" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_row_inner][vc_column_inner width="2/3"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][vc_column_inner width="1/3"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row][vc_column width="1/1"][vc_gmaps size="300"][/vc_column][/vc_row][vc_row][vc_column width="1/1"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:center" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Help section */
$data = array();
$data['name'] = esc_html__( 'Help section', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/2"][vc_toggle title="First question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][vc_toggle title="Second question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][vc_toggle title="Third question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][/vc_column][vc_column width="1/2"][vc_toggle title="Fourth question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][vc_toggle title="Fifth question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][vc_toggle title="Sixth question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][/vc_column][/vc_row][vc_row][vc_column width="1/1"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h3|text_align:center" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Screen description */
$data = array();
$data['name'] = esc_html__( 'Screen description', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/4"][vc_row_inner][vc_column_inner width="1/1"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h3|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][vc_column width="2/4"][vc_single_image alignment="center" border_color="grey" img_link_target="_self"][/vc_column][vc_column width="1/4"][vc_row_inner][vc_column_inner width="1/1"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h3|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Description with round images*/
$data = array();
$data['name'] = esc_html__( 'Description with round images', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/1"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:center" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/3"][vc_single_image alignment="center" style="vc_box_circle" border_color="grey" img_link_target="_self"][/vc_column][vc_column width="1/3"][vc_single_image alignment="center" style="vc_box_circle" border_color="grey" img_link_target="_self"][/vc_column][vc_column width="1/3"][vc_single_image alignment="center" style="vc_box_circle" border_color="grey" img_link_target="_self"][/vc_column][/vc_row][vc_row][vc_column width="1/1"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** FAQ in three columns */
$data = array();
$data['name'] = esc_html__( 'FAQ in three columns', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/1"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:center" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/1"][vc_separator color="grey" style="double"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][vc_toggle title="First question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][vc_toggle title="Second question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][/vc_column][vc_column width="1/3"][vc_toggle title="Third question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][vc_toggle title="Fourth question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][/vc_column][vc_column width="1/3"][vc_toggle title="Fifth question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][vc_toggle title="Sixth question" open="false"]Toggle content goes here, click edit button to change this text.[/vc_toggle][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Centre description */
$data = array();
$data['name'] = esc_html__( 'Centre description', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row css=".vc_custom_1411476739640{padding-top: 50px !important;padding-bottom: 50px !important;background-color: #e8e8e8 !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_column width="1/1"][vc_row_inner][vc_column_inner width="1/3"][/vc_column_inner][vc_column_inner width="1/3"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:center" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column_inner][vc_column_inner width="1/3"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Description with gallery */
$data = array();
$data['name'] = esc_html__( 'Description with gallery', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/3"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_outline" alignment="center"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_outline" alignment="center"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_outline" alignment="center"][/vc_column][vc_column width="1/3"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_outline" alignment="center"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_outline" alignment="center"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_outline" alignment="center"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Centre description with image */
$data = array();
$data['name'] = esc_html__( 'Centre description with image', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row css=".vc_custom_1411476638326{padding-top: 50px !important;padding-bottom: 50px !important;background-color: #eaeaea !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_column width="1/1"][vc_row_inner][vc_column_inner width="1/3"][/vc_column_inner][vc_column_inner width="1/3"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h3|text_align:center" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][/vc_column_inner][vc_column_inner width="1/3"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Description with thumbnails */
$data = array();
$data['name'] = esc_html__( 'Description with thumbnails', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/1"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/4"][vc_single_image alignment="center" border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column][vc_column width="1/4"][vc_single_image alignment="center" border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column][vc_column width="1/4"][vc_single_image alignment="center" border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column][vc_column width="1/4"][vc_single_image alignment="center" border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column][/vc_row][vc_row][vc_column width="1/4"][vc_single_image alignment="center" border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column][vc_column width="1/4"][vc_single_image alignment="center" border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column][vc_column width="1/4"][vc_single_image alignment="center" border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column][vc_column width="1/4"][vc_single_image alignment="center" border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column][/vc_row][vc_row][vc_column width="1/1"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** About with left gallery */
$data = array();
$data['name'] = esc_html__( 'About with left gallery', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/4"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][/vc_column][vc_column width="3/4"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Five image layout */
$data = array();
$data['name'] = esc_html__( 'Five image layout', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="2/3"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_row_inner][vc_column_inner width="1/2"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][vc_column_inner width="1/2"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][vc_column width="1/3"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_rounded"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Accordion news list */
$data = array();
$data['name'] = esc_html__( 'Accordion news list', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column][vc_tta_accordion][vc_tta_section title="Section 1" tab_id="1441873920568-18a8a48a-7614"][vc_row_inner][vc_column_inner width="1/4"][vc_single_image alignment="" style="vc_box_rounded"][/vc_column_inner][vc_column_inner width="3/4"][vc_custom_heading text="This is custom heading element with Google Fonts" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="flat" color="juicy-pink"][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner width="1/4"][vc_single_image alignment="" style="vc_box_rounded"][/vc_column_inner][vc_column_inner width="3/4"][vc_custom_heading text="This is custom heading element with Google Fonts" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="flat" color="juicy-pink"][/vc_column_inner][/vc_row_inner][/vc_tta_section][vc_tta_section title="Section 2" tab_id="1441873920660-a173daba-0456"][vc_row_inner][vc_column_inner width="1/4"][vc_single_image alignment="" style="vc_box_rounded"][/vc_column_inner][vc_column_inner width="3/4"][vc_custom_heading text="This is custom heading element with Google Fonts" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="flat" color="juicy-pink"][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner width="1/4"][vc_single_image alignment="" style="vc_box_rounded"][/vc_column_inner][vc_column_inner width="3/4"][vc_custom_heading text="This is custom heading element with Google Fonts" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="flat" color="juicy-pink"][/vc_column_inner][/vc_row_inner][/vc_tta_section][/vc_tta_accordion][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Product with social icons */
$data = array();
$data['name'] = esc_html__( 'Product with social icons', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/2"][vc_single_image border_color="grey" img_link_target="_self" style="vc_box_border"][/vc_column][vc_column width="1/2"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_row_inner][vc_column_inner width="1/3"][vc_facebook type="standard"][/vc_column_inner][vc_column_inner width="1/3"][vc_tweetmeme type="none"][/vc_column_inner][vc_column_inner width="1/3"][vc_googleplus annotation="none"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Complex news layout */
$data = array();
$data['name'] = esc_html__( 'Complex news layout', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width=""][vc_column width="2/3"][vc_row_inner][vc_column_inner el_class="" width="1/2"][vc_single_image image="" alignment="" style="vc_box_border" border_color="grey" img_link_large="" img_link_target="_self" css_animation=""][/vc_column_inner][vc_column_inner el_class="" width="1/2"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="flat" shape="rounded" color="mulled-wine" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner el_class="" width="1/2"][vc_single_image image="" alignment="" style="vc_box_border" border_color="grey" img_link_large="" img_link_target="_self" css_animation=""][/vc_column_inner][vc_column_inner el_class="" width="1/2"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read more" style="flat" shape="rounded" color="mulled-wine" size="md" align="inline" i_align="left" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" css_animation="" button_block="" add_icon="" i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert"][/vc_column_inner][/vc_row_inner][/vc_column][vc_column width="1/3"][vc_row_inner][vc_column_inner el_class="" width="1/1"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h3|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner el_class="" width="1/1"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h3|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Product list with CTA */
$data = array();
$data['name'] = esc_html__( 'Product list with CTA', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width=""][vc_column width="1/3"][vc_single_image image="" alignment="" style="vc_box_outline" border_color="grey" img_link_large="" img_link_target="_self" css_animation=""][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image image="" alignment="" style="vc_box_outline" border_color="grey" img_link_large="" img_link_target="_self" css_animation=""][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image image="" alignment="" style="vc_box_outline" border_color="grey" img_link_large="" img_link_target="_self" css_animation=""][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row][vc_row full_width=""][vc_column width="1/1"][vc_cta h2="Hey! I am first heading line feel free to change me" h2_google_fonts="font_family:Abril%20Fatface%3Aregular|font_style:400%20regular%3A400%3Anormal" h4_google_fonts="font_family:Abril%20Fatface%3Aregular|font_style:400%20regular%3A400%3Anormal" txt_align="left" shape="rounded" style="classic" color="classic" add_button="right" btn_title="Read more" btn_style="flat" btn_shape="rounded" btn_color="juicy-pink" btn_size="md" btn_align="inline" btn_i_align="left" btn_i_type="fontawesome" btn_i_icon_fontawesome="fas fa-adjust" btn_i_icon_openiconic="vc-oi vc-oi-dial" btn_i_icon_typicons="typcn typcn-adjust-brightness" btn_i_icon_entypo="entypo-icon entypo-icon-note" btn_i_icon_linecons="vc_li vc_li-heart" i_type="fontawesome" i_icon_fontawesome="fas fa-adjust" i_icon_openiconic="vc-oi vc-oi-dial" i_icon_typicons="typcn typcn-adjust-brightness" i_icon_entypo="entypo-icon entypo-icon-note" i_icon_linecons="vc_li vc_li-heart" i_color="blue" i_background_color="grey" i_size="md" use_custom_fonts_h2="" use_custom_fonts_h4="" btn_button_block="" btn_add_icon="" btn_i_icon_pixelicons="vc_pixel_icon vc_pixel_icon-alert" i_on_border=""]I am promo text. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_cta][/vc_column][/vc_row][vc_row full_width=""][vc_column width="1/3"][vc_single_image image="" alignment="" style="vc_box_outline" border_color="grey" img_link_large="" img_link_target="_self" css_animation=""][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image image="" alignment="" style="vc_box_outline" border_color="grey" img_link_large="" img_link_target="_self" css_animation=""][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image image="" alignment="" style="vc_box_outline" border_color="grey" img_link_large="" img_link_target="_self" css_animation=""][vc_column_text css_animation=""]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Intro with features */
$data = array();
$data['name'] = esc_html__( 'Intro with features', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/1"][vc_single_image style="vc_box_rounded" border_color="grey" img_link_target="_self"][/vc_column][/vc_row][vc_row css=".vc_custom_1411479622940{padding-top: 10px !important;padding-bottom: 10px !important;background-color: #ededed !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_column width="1/2"][vc_single_image style="vc_box_rounded" border_color="grey" img_link_target="_self"][/vc_column][vc_column width="1/2"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row][vc_row css=".vc_custom_1411479636520{padding-top: 10px !important;padding-bottom: 10px !important;background-color: #ededed !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_column width="1/2"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/2"][vc_single_image style="vc_box_rounded" border_color="grey" img_link_target="_self"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Image gallery with description */
$data = array();
$data['name'] = esc_html__( 'Image gallery with description', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/1"][vc_gallery type="flexslider_fade" interval="3" onclick="link_image" custom_links_target="_self"][/vc_column][/vc_row][vc_row css=".vc_custom_1411478929680{padding-top: 25px !important;padding-bottom: 25px !important;background-color: #e8e8e8 !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_column width="1/4"][vc_column_text]<p style="text-align: right;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][vc_column width="1/2"][vc_single_image alignment="center" style="vc_box_rounded" border_color="grey" img_link_target="_self"][/vc_column][vc_column width="1/4"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Team members */
$data = array();
$data['name'] = esc_html__( 'Team members', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/1"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:center" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][/vc_column][/vc_row][vc_row][vc_column width="1/4"][vc_single_image alignment="center" style="vc_box_circle" border_color="grey" img_link_target="_self"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][vc_column width="1/4"][vc_single_image alignment="center" style="vc_box_circle" border_color="grey" img_link_target="_self"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][vc_column width="1/4"][vc_single_image alignment="center" style="vc_box_circle" border_color="grey" img_link_target="_self"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][vc_column width="1/4"][vc_single_image alignment="center" style="vc_box_circle" border_color="grey" img_link_target="_self"][vc_column_text]<p style="text-align: center;">I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Large image with thumbnails */
$data = array();
$data['name'] = esc_html__( 'Large image with thumbnails', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/2"][vc_single_image style="vc_box_rounded" border_color="grey" img_link_target="_self"][/vc_column][vc_column width="1/2"][vc_row_inner][vc_column_inner width="1/2"][vc_single_image style="vc_box_rounded" border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][vc_column_inner width="1/2"][vc_single_image style="vc_box_rounded" border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner width="1/2"][vc_single_image style="vc_box_rounded" border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][vc_column_inner width="1/2"][vc_single_image style="vc_box_rounded" border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Complex news layout II */
$data = array();
$data['name'] = esc_html__( 'Complex news layout II', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/3"][vc_single_image alignment="center" style="vc_box_rounded" border_color="grey" img_link_target="_self"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_row_inner][vc_column_inner width="1/1"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner width="1/1"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][vc_column width="1/3"][vc_row_inner][vc_column_inner width="1/2"][vc_single_image style="vc_box_rounded" border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][vc_column_inner width="1/2"][vc_single_image style="vc_box_rounded" border_color="grey" img_link_target="_self"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Service description layout */
$data = array();
$data['name'] = esc_html__( 'Service description layout', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/3"][vc_single_image alignment="center" style="vc_box_rounded" border_color="grey" img_link_target="_self"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][/vc_column][vc_column width="1/3"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image alignment="center" style="vc_box_rounded" border_color="grey" img_link_target="_self"][vc_custom_heading text="This is custom heading element with Google Fonts" font_container="tag:h2|text_align:left" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Articles with headings */
$data = array();
$data['name'] = esc_html__( 'Articles with headings', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row" css=".vc_custom_1436530910893{background-color: #32a363 !important;}"][vc_column][vc_empty_space height="200px"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][vc_custom_heading text="CUSTOM HEADING FOR ROW" font_container="tag:h1|text_align:left" use_theme_fonts="yes" css=".vc_custom_1436530789421{margin-top: 0px !important;}"][/vc_column][vc_column width="1/3"][vc_custom_heading text="Heading with Theme Font" font_container="tag:h3|text_align:left" use_theme_fonts="yes" css=".vc_custom_1436530550784{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1436530603605{margin-bottom: 15px !important;}"]
This is a block where you can quickly describe less important services or side services which do not require lot of attention or maybe are the part of the main product or service.
[/vc_column_text][/vc_column][vc_column width="1/3"][vc_custom_heading text="Heading with Theme Font" font_container="tag:h3|text_align:left" use_theme_fonts="yes" css=".vc_custom_1436530550784{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1436530603605{margin-bottom: 15px !important;}"]
This is a block where you can quickly describe less important services or side services which do not require lot of attention or maybe are the part of the main product or service.
[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column][vc_separator][/vc_column][/vc_row][vc_row][vc_column width="1/3"][vc_custom_heading text="CUSTOM HEADING FOR ROW" font_container="tag:h1|text_align:left" use_theme_fonts="yes" css=".vc_custom_1436530789421{margin-top: 0px !important;}"][/vc_column][vc_column width="1/3"][vc_custom_heading text="Heading with Theme Font" font_container="tag:h3|text_align:left" use_theme_fonts="yes" css=".vc_custom_1436530550784{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1436530603605{margin-bottom: 15px !important;}"]
This is a block where you can quickly describe less important services or side services which do not require lot of attention or maybe are the part of the main product or service.
[/vc_column_text][/vc_column][vc_column width="1/3"][vc_custom_heading text="Heading with Theme Font" font_container="tag:h3|text_align:left" use_theme_fonts="yes" css=".vc_custom_1436530550784{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1436530603605{margin-bottom: 15px !important;}"]
This is a block where you can quickly describe less important services or side services which do not require lot of attention or maybe are the part of the main product or service.
[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Call to Action section */
$data = array();
$data['name'] = esc_html__( 'Call to Action section', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row" parallax="content-moving" css=".vc_custom_1434539542642{padding-top: 100px !important;padding-bottom: 50px !important;background-color: #587199 !important;}"][vc_column][vc_video][vc_custom_heading text="Call to Action Section with Custom Heading" font_container="tag:h2|text_align:center|color:%23ffffff" use_theme_fonts="yes" css=".vc_custom_1434539595945{padding-bottom: 10px !important;}"][vc_column_text css=".vc_custom_1434539588856{margin-bottom: 0px !important;}"]
Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
[/vc_column_text][vc_row_inner][vc_column_inner width="1/2"][vc_btn title="Purchase Now" style="flat" color="danger" align="right"][/vc_column_inner][vc_column_inner width="1/2"][vc_btn title="Purchase Now" style="outline" color="white" align="left"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Charts section */
$data = array();
$data['name'] = esc_html__( 'Charts section', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row" css=".vc_custom_1434544165859{padding-top: 100px !important;padding-bottom: 100px !important;background-color: #eaeaea !important;}"][vc_column][vc_custom_heading text="CUSTOM HEADING TITLE OF THE SECTION" font_container="tag:h2|text_align:center" use_theme_fonts="yes" css=".vc_custom_1434544875177{margin-top: 0px !important;}"][vc_row_inner][vc_column_inner width="1/4"][vc_round_chart type="doughnut" stroke_width="2" stroke_color="custom" legend="" values="%5B%7B%22title%22%3A%22One%22%2C%22value%22%3A%2260%22%2C%22color%22%3A%22orange%22%7D%2C%7B%22title%22%3A%22Two%22%2C%22value%22%3A%2240%22%2C%22color%22%3A%22sandy-brown%22%7D%5D" custom_stroke_color="#ebebeb"][/vc_column_inner][vc_column_inner width="1/4"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" font_container="tag:h3|text_align:left" use_theme_fonts="yes" css=".vc_custom_1434544764669{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1434542828932{margin-bottom: 15px !important;}"]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][vc_btn title="Read More" style="flat" color="vista-blue" align="left"][/vc_column_inner][vc_column_inner width="1/4"][vc_round_chart type="doughnut" stroke_width="2" stroke_color="custom" legend="" values="%5B%7B%22title%22%3A%22Two%22%2C%22value%22%3A%2220%22%2C%22color%22%3A%22sandy-brown%22%7D%2C%7B%22title%22%3A%22One%22%2C%22value%22%3A%2280%22%2C%22color%22%3A%22orange%22%7D%5D" custom_stroke_color="#ebebeb"][/vc_column_inner][vc_column_inner width="1/4"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" font_container="tag:h3|text_align:left" use_theme_fonts="yes" css=".vc_custom_1434544769752{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1434542828932{margin-bottom: 15px !important;}"]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][vc_btn title="Read More" style="flat" color="vista-blue" align="left"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row][vc_column][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Chess Grid */
$data = array();
$data['name'] = esc_html__( 'Chess Grid', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row" css=".vc_custom_1434538871508{margin-bottom: 0px !important;}"][vc_column width="1/3"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" use_theme_fonts="yes"][vc_column_text]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][vc_btn title="READ MORE" style="flat" color="purple" align="left"][/vc_column][vc_column width="1/3"][vc_single_image img_size="large" css=".vc_custom_1434538915151{margin-right: -15px !important;margin-left: -15px !important;}"][/vc_column][vc_column width="1/3"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" use_theme_fonts="yes"][vc_column_text]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][vc_btn title="READ MORE" style="flat" color="purple" align="left"][/vc_column][/vc_row][vc_row full_width="stretch_row"][vc_column width="1/3"][vc_single_image img_size="large" css=".vc_custom_1434538921676{margin-right: -15px !important;margin-left: -15px !important;}"][/vc_column][vc_column width="1/3"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" use_theme_fonts="yes"][vc_column_text]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][vc_btn title="READ MORE" style="flat" color="purple" align="left"][/vc_column][vc_column width="1/3"][vc_single_image img_size="large" css=".vc_custom_1434538926953{margin-right: -15px !important;margin-left: -15px !important;}"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Features and articles */
$data = array();
$data['name'] = esc_html__( 'Features and articles', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/4"][vc_icon icon_fontawesome="fa fa-anchor" color="chino" size="lg" align="center"][vc_custom_heading text="Feature One" font_container="tag:h4|text_align:center" use_theme_fonts="yes"][vc_column_text]

Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit.

[/vc_column_text][/vc_column][vc_column width="1/4"][vc_icon icon_fontawesome="fa fa-car" color="chino" size="lg" align="center"][vc_custom_heading text="Feature Two" font_container="tag:h4|text_align:center" use_theme_fonts="yes"][vc_column_text]

Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit.

[/vc_column_text][/vc_column][vc_column width="1/4"][vc_icon icon_fontawesome="fa fa-cutlery" color="chino" size="lg" align="center"][vc_custom_heading text="Feature Three" font_container="tag:h4|text_align:center" use_theme_fonts="yes"][vc_column_text]

Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit.

[/vc_column_text][/vc_column][vc_column width="1/4"][vc_icon icon_fontawesome="fa fa-life-ring" color="chino" size="lg" align="center"][vc_custom_heading text="Feature Four" font_container="tag:h4|text_align:center" use_theme_fonts="yes"][vc_column_text]

Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit.

[/vc_column_text][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1435233845530{padding-top: 50px !important;padding-bottom: 50px !important;background-color: #f7f7f7 !important;}"][vc_column width="1/2"][vc_single_image img_size="500x200" alignment="center"][/vc_column][vc_column width="1/2"][vc_custom_heading text="Custom Heading Title" use_theme_fonts="yes"][vc_column_text]

Vivamus et risus in purus consequat interdum. Nam hendrerit euismod quam imperdiet maximus. Duis id eros eu lectus tempor interdum. Duis nec commodo enim. Proin lobortis sapien vitae eleifend tincidunt.

[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/4"][/vc_column][vc_column width="1/2"][vc_single_image img_size="500x200" alignment="center"][vc_custom_heading text="Article Title" font_container="tag:h3|text_align:center" use_theme_fonts="yes"][vc_column_text]

Vivamus et risus in purus consequat interdum. Nam hendrerit euismod quam imperdiet maximus. Duis id eros eu lectus tempor interdum. Duis nec commodo enim. Proin lobortis sapien vitae eleifend tincidunt.

[/vc_column_text][vc_btn title="Read More" color="chino" align="center"][/vc_column][vc_column width="1/4"][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_single_image img_size="500x200" alignment="center"][vc_custom_heading text="Article Title" font_container="tag:h3|text_align:center" use_theme_fonts="yes"][vc_column_text]

Vivamus et risus in purus consequat interdum. Nam hendrerit euismod quam imperdiet maximus. Duis id eros eu lectus tempor interdum. Duis nec commodo enim. Proin lobortis sapien vitae eleifend tincidunt.

[/vc_column_text][vc_btn title="Read More" color="chino" align="center"][/vc_column][vc_column width="1/2"][vc_single_image img_size="500x200" alignment="center"][vc_custom_heading text="Article Title" font_container="tag:h3|text_align:center" use_theme_fonts="yes"][vc_column_text]

Vivamus et risus in purus consequat interdum. Nam hendrerit euismod quam imperdiet maximus. Duis id eros eu lectus tempor interdum. Duis nec commodo enim. Proin lobortis sapien vitae eleifend tincidunt.

[/vc_column_text][vc_btn title="Read More" color="chino" align="center"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Features and charts */
$data = array();
$data['name'] = esc_html__( 'Features and charts', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/3"][vc_icon type="openiconic" icon_openiconic="vc-oi vc-oi-comment-inv" color="white" background_style="rounded-less" background_color="blue" size="lg" align="center"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" font_container="tag:h3|text_align:center" use_theme_fonts="yes" css=".vc_custom_1436536470111{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1436536478730{margin-bottom: 15px !important;}"]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column][vc_column width="1/3"][vc_icon type="openiconic" icon_openiconic="vc-oi vc-oi-brush" color="white" background_style="rounded-less" background_color="blue" size="lg" align="center"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" font_container="tag:h3|text_align:center" use_theme_fonts="yes" css=".vc_custom_1436536470111{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1436536478730{margin-bottom: 15px !important;}"]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column][vc_column width="1/3"][vc_icon type="openiconic" icon_openiconic="vc-oi vc-oi-clock" color="white" background_style="rounded-less" background_color="blue" size="lg" align="center"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" font_container="tag:h3|text_align:center" use_theme_fonts="yes" css=".vc_custom_1436536470111{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1436536478730{margin-bottom: 15px !important;}"]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1436536173326{padding-top: 70px !important;padding-bottom: 50px !important;background-color: #4c7ac9 !important;}"][vc_column][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" font_container="tag:h2|text_align:center|color:%23f9f9f9" use_theme_fonts="yes" css=".vc_custom_1436536188188{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1436536318151{margin-bottom: 15px !important;}"]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/4"][vc_round_chart type="doughnut" stroke_width="2" legend=""][/vc_column][vc_column width="1/4"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" font_container="tag:h3|text_align:left" use_theme_fonts="yes" css=".vc_custom_1434544764669{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1434542828932{margin-bottom: 15px !important;}"]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column][vc_column width="1/4"][vc_round_chart type="doughnut" stroke_width="2" legend="" values="%5B%7B%22title%22%3A%22Two%22%2C%22value%22%3A%2240%22%2C%22color%22%3A%22pink%22%7D%2C%7B%22title%22%3A%22One%22%2C%22value%22%3A%2260%22%2C%22color%22%3A%22blue%22%7D%5D"][/vc_column][vc_column width="1/4"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" font_container="tag:h3|text_align:left" use_theme_fonts="yes" css=".vc_custom_1434544764669{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1434542828932{margin-bottom: 15px !important;}"]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Features with video parallax */
$data = array();
$data['name'] = esc_html__( 'Features with video parallax', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row" video_bg="yes" video_bg_parallax="content-moving" css=".vc_custom_1434538448279{padding-top: 250px !important;padding-bottom: 35px !important;}"][vc_column width="1/3"][vc_icon icon_fontawesome="fa fa-anchor" color="white" background_style="rounded" background_color="purple" size="lg" align="center"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" font_container="tag:h4|text_align:center|color:%23ffffff" use_theme_fonts="yes" css=".vc_custom_1434538351196{padding-bottom: 10px !important;}"][vc_column_text]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column][vc_column width="1/3"][vc_icon icon_fontawesome="fa fa-magic" color="white" background_style="rounded" background_color="purple" size="lg" align="center"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" font_container="tag:h4|text_align:center|color:%23ffffff" use_theme_fonts="yes" css=".vc_custom_1434538351196{padding-bottom: 10px !important;}"][vc_column_text]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column][vc_column width="1/3"][vc_icon icon_fontawesome="fa fa-eyedropper" color="white" background_style="rounded" background_color="purple" size="lg" align="center"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" font_container="tag:h4|text_align:center|color:%23ffffff" use_theme_fonts="yes" css=".vc_custom_1434538351196{padding-bottom: 10px !important;}"][vc_column_text]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Features with full width promo */
$data = array();
$data['name'] = esc_html__( 'Features with full width promo', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row"][vc_column width="1/3"][vc_single_image img_size="large"][vc_custom_heading text="Custom Heading for Feature Title" use_theme_fonts="yes" css=".vc_custom_1434543954750{margin-top: 0px !important;}"][vc_column_text]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image img_size="large"][vc_custom_heading text="Custom Heading for Feature Title" use_theme_fonts="yes" css=".vc_custom_1434543954750{margin-top: 0px !important;}"][vc_column_text]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image img_size="large"][vc_custom_heading text="Custom Heading for Feature Title" use_theme_fonts="yes" css=".vc_custom_1434543954750{margin-top: 0px !important;}"][vc_column_text]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column][/vc_row][vc_row full_width="stretch_row" parallax="content-moving" css=".vc_custom_1434543894706{padding-top: 50px !important;padding-bottom: 50px !important;background-color: #34a875 !important;}"][vc_column][vc_custom_heading text="Custom Heading Element for Promo Block" font_container="tag:h2|text_align:center|color:%23ffffff" use_theme_fonts="yes" css=".vc_custom_1434543916938{padding-bottom: 10px !important;}"][vc_column_text css=".vc_custom_1434539588856{margin-bottom: 0px !important;}"]

Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit.

[/vc_column_text][/vc_column][/vc_row][vc_row full_width="stretch_row"][vc_column width="1/3"][vc_single_image img_size="large"][vc_custom_heading text="Custom Heading for Feature Title" use_theme_fonts="yes" css=".vc_custom_1434543954750{margin-top: 0px !important;}"][vc_column_text]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image img_size="large"][vc_custom_heading text="Custom Heading for Feature Title" use_theme_fonts="yes" css=".vc_custom_1434543954750{margin-top: 0px !important;}"][vc_column_text]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image img_size="large"][vc_custom_heading text="Custom Heading for Feature Title" use_theme_fonts="yes" css=".vc_custom_1434543954750{margin-top: 0px !important;}"][vc_column_text]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Full height hero section */
$data = array();
$data['name'] = esc_html__( 'Full height hero section', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row" full_height="yes" css=".vc_custom_1436531990024{background-color: #32a363 !important;}"][vc_column][vc_empty_space height="300px"][vc_row_inner][vc_column_inner width="1/6"][vc_icon icon_fontawesome="fa fa-anchor" color="white" size="lg" align="center" css_animation="appear"][/vc_column_inner][vc_column_inner width="3/6"][vc_custom_heading text="CUSTOM HEADING FOR FULL HEIGHT HERO ROW" font_container="tag:h1|text_align:left|color:%23ffffff" use_theme_fonts="yes" css=".vc_custom_1436532193902{margin-top: 0px !important;}"][vc_column_text]

This section looks good with color background, background image and even video background and can be used as a nice Hero type header for any type of site or introduction block because of full height row.

[/vc_column_text][vc_separator color="sandy_brown" align="align_left" border_width="5" el_width="20"][/vc_column_inner][vc_column_inner width="2/6"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Full height with transparent block */
$data = array();
$data['name'] = esc_html__( 'Full height with transparent block', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row" full_height="yes" css=".vc_custom_1436535126152{margin-bottom: 0px !important;background-color: #319e60 !important;}"][vc_column][vc_empty_space height="300px"][vc_row_inner][vc_column_inner width="1/2"][/vc_column_inner][vc_column_inner width="1/2" css=".vc_custom_1436535211249{padding: 25px !important;background-color: rgba(10,0,0,0.5) !important;*background-color: rgb(10,0,0) !important;}"][vc_custom_heading text="CUSTOM HEADING FOR FULL HEIGHT HERO ROW" font_container="tag:h1|text_align:left|color:%23ffffff" use_theme_fonts="yes" css=".vc_custom_1436532193902{margin-top: 0px !important;}"][vc_column_text]

This section looks good with color background, background image and even video background and can be used as a nice Hero type header for any type of site or introduction block because of full height row.

[/vc_column_text][vc_btn title="READ MORE" style="outline" shape="square" color="white"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Full height parallax */
$data = array();
$data['name'] = esc_html__( 'Full height parallax', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row" full_height="yes" parallax="content-moving" css=".vc_custom_1434539237836{background-color: #595959 !important;}"][vc_column width="1/3"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" font_container="tag:h2|font_size:50|text_align:left|color:%23ffffff" use_theme_fonts="yes" css=".vc_custom_1434539145446{padding-bottom: 20px !important;}"][vc_btn title="READ MORE" style="flat" color="success" align="center" button_block="true"][/vc_column][vc_column width="1/3"][/vc_column][vc_column width="1/3"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Header section with features */
$data = array();
$data['name'] = esc_html__( 'Header section with features', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT

[vc_row][vc_column width="1/4"][vc_custom_heading text="Custom Heading Title" use_theme_fonts="yes"][vc_column_text]

WordPress is a free and open-source tool - features include a plugin architecture and a template system. WordPress was used by more than 23.3% of the top 10 million websites as of January 2015. WordPress is the most popular blogging system in use on the Web, at more than 60 million websites.

[/vc_column_text][/vc_column][vc_column width="3/4" css=".vc_custom_1436799832666{background-color: #f79467 !important;}"][vc_empty_space height="200px"][vc_custom_heading text="Custom Heading Title" font_container="tag:h2|text_align:left|color:%23ffffff" use_theme_fonts="yes" css=".vc_custom_1436799543928{padding-left: 35px !important;}"][vc_column_text css=".vc_custom_1436799840479{padding-bottom: 50px !important;padding-left: 35px !important;}"]

Vivamus et risus in purus consequat interdum. Nam hendrerit euismod quam imperdiet maximus. Duis id eros eu lectus tempor interdum. Duis nec commodo enim. Proin lobortis sapien vitae eleifend tincidunt.

[/vc_column_text][/vc_column][/vc_row][vc_row][vc_column width="1/4"][/vc_column][vc_column width="1/4"][vc_icon icon_fontawesome="fa fa-credit-card" color="white" background_style="boxed" background_color="sandy_brown" size="lg" align="center"][vc_custom_heading text="Feature One" font_container="tag:h4|text_align:center" use_theme_fonts="yes"][vc_column_text]

Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit.

[/vc_column_text][/vc_column][vc_column width="1/4"][vc_icon icon_fontawesome="fa fa-inbox" color="white" background_style="boxed" background_color="sandy_brown" size="lg" align="center"][vc_custom_heading text="Feature Two" font_container="tag:h4|text_align:center" use_theme_fonts="yes"][vc_column_text]

Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit.

[/vc_column_text][/vc_column][vc_column width="1/4"][vc_icon icon_fontawesome="fa fa-paper-plane" color="white" background_style="boxed" background_color="sandy_brown" size="lg" align="center"][vc_custom_heading text="Feature Three" font_container="tag:h4|text_align:center" use_theme_fonts="yes"][vc_column_text]

Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit.

[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Helps with icons */
$data = array();
$data['name'] = esc_html__( 'Helps with icons', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/6"][vc_icon icon_fontawesome="fa fa-video-camera" color="purple" size="lg" align="center"][/vc_column][vc_column width="2/6"][vc_toggle title="Toggle Title Goes Here" style="text_only" open="true" el_id="1435236109681-5197967b-614c"]Ut elit nisl, efficitur sit amet augue ut, venenatis lobortis est. Nullam luctus sapien eu enim tristique porta. Nulla quis libero magna. Morbi ultrices nunc lacus, eu ultricies urna suscipit non. Aliquam rutrum sem eu sapien bibendum efficitur. Donec nisl nunc, suscipit et sollicitudin sed, vulputate at urna. Proin tincidunt iaculis maximus.[/vc_toggle][/vc_column][vc_column width="1/6"][vc_icon icon_fontawesome="fa fa-tasks" color="purple" size="lg" align="center"][/vc_column][vc_column width="2/6"][vc_toggle title="Toggle Title Goes Here" style="text_only" el_id="1435236274452-79d18059-9dc1"]Ut elit nisl, efficitur sit amet augue ut, venenatis lobortis est. Nullam luctus sapien eu enim tristique porta. Nulla quis libero magna. Morbi ultrices nunc lacus, eu ultricies urna suscipit non. Aliquam rutrum sem eu sapien bibendum efficitur. Donec nisl nunc, suscipit et sollicitudin sed, vulputate at urna. Proin tincidunt iaculis maximus.[/vc_toggle][/vc_column][/vc_row][vc_row][vc_column width="1/6"][vc_icon icon_fontawesome="fa fa-leaf" color="purple" size="lg" align="center"][/vc_column][vc_column width="2/6"][vc_toggle title="Toggle Title Goes Here" style="text_only" el_id="1435236288705-f99d6e32-4a28"]Ut elit nisl, efficitur sit amet augue ut, venenatis lobortis est. Nullam luctus sapien eu enim tristique porta. Nulla quis libero magna. Morbi ultrices nunc lacus, eu ultricies urna suscipit non. Aliquam rutrum sem eu sapien bibendum efficitur. Donec nisl nunc, suscipit et sollicitudin sed, vulputate at urna. Proin tincidunt iaculis maximus.[/vc_toggle][/vc_column][vc_column width="1/6"][vc_icon icon_fontawesome="fa fa-lock" color="purple" size="lg" align="center"][/vc_column][vc_column width="2/6"][vc_toggle title="Toggle Title Goes Here" style="text_only" el_id="1435236288706-ef36a7b7-5c71"]Ut elit nisl, efficitur sit amet augue ut, venenatis lobortis est. Nullam luctus sapien eu enim tristique porta. Nulla quis libero magna. Morbi ultrices nunc lacus, eu ultricies urna suscipit non. Aliquam rutrum sem eu sapien bibendum efficitur. Donec nisl nunc, suscipit et sollicitudin sed, vulputate at urna. Proin tincidunt iaculis maximus.[/vc_toggle][/vc_column][/vc_row][vc_row][vc_column width="1/6"][vc_icon icon_fontawesome="fa fa-map-marker" color="purple" size="lg" align="center"][/vc_column][vc_column width="2/6"][vc_toggle title="Toggle Title Goes Here" style="text_only" el_id="1435236301680-f9740b97-8983"]Ut elit nisl, efficitur sit amet augue ut, venenatis lobortis est. Nullam luctus sapien eu enim tristique porta. Nulla quis libero magna. Morbi ultrices nunc lacus, eu ultricies urna suscipit non. Aliquam rutrum sem eu sapien bibendum efficitur. Donec nisl nunc, suscipit et sollicitudin sed, vulputate at urna. Proin tincidunt iaculis maximus.[/vc_toggle][/vc_column][vc_column width="1/6"][vc_icon icon_fontawesome="fa fa-paint-brush" color="purple" size="lg" align="center"][/vc_column][vc_column width="2/6"][vc_toggle title="Toggle Title Goes Here" style="text_only" el_id="1435236301681-90cd844c-c87e"]Ut elit nisl, efficitur sit amet augue ut, venenatis lobortis est. Nullam luctus sapien eu enim tristique porta. Nulla quis libero magna. Morbi ultrices nunc lacus, eu ultricies urna suscipit non. Aliquam rutrum sem eu sapien bibendum efficitur. Donec nisl nunc, suscipit et sollicitudin sed, vulputate at urna. Proin tincidunt iaculis maximus.[/vc_toggle][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Plain articles */
$data = array();
$data['name'] = esc_html__( 'Plain articles', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column][vc_custom_heading text="This is article title" font_container="tag:h2|text_align:left|color:%232a2a2a" use_theme_fonts="yes"][vc_separator color="black" align="align_left" border_width="3"][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_column_text]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec sit amet augue pretium, lacinia nibh vitae, feugiat tellus. Quisque rhoncus eget velit a malesuada. Nunc non felis lacus. Morbi orci ligula, tempor a turpis vulputate, fermentum feugiat orci. Vestibulum volutpat ligula erat, at feugiat libero ultricies nec. Nam tincidunt luctus mi ut vestibulum. Integer consequat ullamcorper nisi vitae vehicula. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Proin ipsum odio, luctus in vehicula tempor, bibendum at nisl. Proin in facilisis mauris, vitae iaculis felis. Etiam auctor quis tellus quis laoreet. Fusce pretium ex at posuere viverra. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Aenean in est nec justo lobortis vestibulum eget vel mauris.

Nullam sed nunc quis est accumsan finibus et eget erat. Integer tincidunt leo eu nisi pretium, id mattis urna mollis. Cras feugiat urna eu enim tristique, nec tristique justo semper. Duis vel diam tortor. Curabitur iaculis porttitor ante, at dictum nibh volutpat sit amet. Nullam eu quam ac lacus posuere lacinia. Ut interdum dolor et quam dictum, at rhoncus magna commodo. Aliquam tempus ex tristique mi ullamcorper tristique. Praesent vitae vehicula mi. Praesent tempus leo elit, non condimentum mauris vulputate non. Aliquam lorem neque, pulvinar ut luctus sit amet, tempus ac metus.

&nbsp;[/vc_column_text][/vc_column][vc_column width="1/2"][vc_column_text]Cras pulvinar lorem nibh, eget feugiat diam egestas ac. Suspendisse porta tellus ut erat posuere, eget porttitor metus vehicula. Praesent luctus non lectus sit amet rutrum. Nulla consectetur felis et justo vehicula tempor. Pellentesque sed venenatis ligula. Aliquam aliquet sem id nisi luctus vulputate. Mauris pretium lorem ex, eu placerat orci euismod ac. Nulla facilisi. Etiam tortor lectus, dignissim eget dapibus vitae, posuere ut mauris. Nunc ullamcorper augue imperdiet, convallis metus vel, dignissim lectus. Pellentesque vulputate volutpat pellentesque. Duis tristique ex sed sapien lacinia aliquam. Cras eu nulla ut tortor molestie molestie vel ac quam. Aenean imperdiet nibh eu metus aliquet porttitor.[/vc_column_text][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1434546213787{padding-top: 25px !important;background-color: #2a2a2a !important;}"][vc_column][vc_cta shape="square" style="flat" color="black" add_button="right" btn_title="Read More" btn_style="outline" btn_shape="square" btn_color="white" btn_size="sm" btn_align="center"]I am promo text. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_cta][/vc_column][/vc_row][vc_row][vc_column][vc_custom_heading text="Related articles" font_container="tag:h2|text_align:left|color:%232a2a2a" use_theme_fonts="yes"][vc_separator color="black" align="align_left" border_width="3"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][vc_custom_heading text="Related article title" font_container="tag:h3|text_align:center|color:%232a2a2a" use_theme_fonts="yes"][vc_column_text]<p style="text-align: center;">Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Proin ipsum odio, luctus in vehicula tempor, bibendum at nisl. Proin in facilisis mauris, vitae iaculis felis. Etiam auctor quis tellus quis laoreet. Fusce pretium ex at posuere viverra.</p>[/vc_column_text][vc_btn title="<strong>Read More</strong>" style="outline" shape="square" color="black" size="sm" align="center"][/vc_column][vc_column width="1/3"][vc_custom_heading text="Related article title" font_container="tag:h3|text_align:center|color:%232a2a2a" use_theme_fonts="yes"][vc_column_text]<p style="text-align: center;">Proin in facilisis mauris, vitae iaculis felis. Etiam auctor quis tellus quis laoreet. Fusce pretium ex at posuere viverra. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Aenean in est nec justo lobortis vestibulum eget vel mauris.</p>[/vc_column_text][vc_btn title="<strong>Read More</strong>" style="outline" shape="square" color="black" size="sm" align="center"][/vc_column][vc_column width="1/3"][vc_custom_heading text="Related article title" font_container="tag:h3|text_align:center|color:%232a2a2a" use_theme_fonts="yes"][vc_column_text]<p style="text-align: center;">Duis vel diam tortor. Curabitur iaculis porttitor ante, at dictum nibh volutpat sit amet. Nullam eu quam ac lacus posuere lacinia. Ut interdum dolor et quam dictum, at rhoncus magna commodo. Aliquam tempus ex tristique mi ullamcorper tristique. Praesent vitae vehicula mi. Praesent tempus leo elit, non condimentum mauris vulputate non.</p>[/vc_column_text][vc_btn title="<strong>Read More</strong>" style="outline" shape="square" color="black" size="sm" align="center"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Post portfolio */
$data = array();
$data['name'] = esc_html__( 'Post portfolio', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column][vc_basic_grid max_items="" style="pagination" items_per_page="8" element_width="3" gap="0" item="mediaGrid_ScaleWithRotation" grid_id="vc_gid:1436801351792-834976e6-1ef2-5" paging_animation_in="none"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][vc_custom_heading text="CUSTOM HEADING TITLE GOES HERE" font_container="tag:h2|font_size:40|text_align:left|line_height:1" use_theme_fonts="yes" css=".vc_custom_1435235172377{margin-top: 0px !important;}"][vc_separator align="align_left" border_width="3" el_width="50"][/vc_column][vc_column width="1/3"][vc_column_text]Ut elit nisl, efficitur sit amet augue ut, venenatis lobortis est. Nullam luctus sapien eu enim tristique porta. Nulla quis libero magna. Morbi ultrices nunc lacus, eu ultricies urna suscipit non. Aliquam rutrum sem eu sapien bibendum efficitur. Donec nisl nunc, suscipit et sollicitudin sed, vulputate at urna. Proin tincidunt iaculis maximus. Praesent aliquam orci sed augue euismod, eu tincidunt quam convallis. Sed eget erat scelerisque, scelerisque odio eu, sodales dui. Sed sed enim sed enim rhoncus commodo. Nunc vehicula faucibus elit ac tempus. Nullam quis orci rhoncus, dignissim mi eget, placerat massa.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_column_text]Aliquam rutrum sem eu sapien bibendum efficitur. Donec nisl nunc, suscipit et sollicitudin sed, vulputate at urna. Proin tincidunt iaculis maximus. Praesent aliquam orci sed augue euismod, eu tincidunt quam convallis. Sed eget erat scelerisque, scelerisque odio eu, sodales dui. Sed sed enim sed enim rhoncus commodo. Nunc vehicula faucibus elit ac tempus. Nullam quis orci rhoncus, dignissim mi eget, placerat massa.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Product introduction */
$data = array();
$data['name'] = esc_html__( 'Product introduction', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row" parallax="content-moving" css=".vc_custom_1436530001615{padding-top: 100px !important;padding-bottom: 50px !important;background-color: #499b7a !important;}"][vc_column width="1/2"][vc_custom_heading text="Custom Heading with Theme Font" font_container="tag:h2|text_align:left|color:%23ffffff" use_theme_fonts="yes" css=".vc_custom_1436530166522{padding-bottom: 10px !important;}"][vc_column_text]

This section is a perfect place to display introduction description for your products and services with an option to access more information by clicking "Read More" button.

[/vc_column_text][vc_btn title="Read More" style="outline" shape="square" color="white" align="left"][/vc_column][vc_column width="1/2"][vc_single_image img_size="medium" alignment="center" style="vc_box_rounded"][/vc_column][/vc_row][vc_row][vc_column width="1/3"][vc_custom_heading text="Heading with Theme Font" font_container="tag:h3|text_align:left" use_theme_fonts="yes" css=".vc_custom_1436530550784{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1436530603605{margin-bottom: 15px !important;}"]

This is a block where you can quickly describe less important services or side services which do not require lot of attention or maybe are the part of the main product or service.

[/vc_column_text][/vc_column][vc_column width="1/3"][vc_custom_heading text="Heading with Theme Font" font_container="tag:h3|text_align:left" use_theme_fonts="yes" css=".vc_custom_1436530550784{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1436530603605{margin-bottom: 15px !important;}"]

This is a block where you can quickly describe less important services or side services which do not require lot of attention or maybe are the part of the main product or service.

[/vc_column_text][/vc_column][vc_column width="1/3"][vc_custom_heading text="Heading with Theme Font" font_container="tag:h3|text_align:left" use_theme_fonts="yes" css=".vc_custom_1436530550784{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1436530603605{margin-bottom: 15px !important;}"]

This is a block where you can quickly describe less important services or side services which do not require lot of attention or maybe are the part of the main product or service.

[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Services with block buttons */
$data = array();
$data['name'] = esc_html__( 'Services with block buttons', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row"][vc_column width="1/3"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" use_theme_fonts="yes" css=".vc_custom_1434542653233{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1434542828932{margin-bottom: 15px !important;}"]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][vc_single_image img_size="large"][/vc_column][vc_column width="1/3"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" use_theme_fonts="yes" css=".vc_custom_1434542653233{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1434542828932{margin-bottom: 15px !important;}"]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][vc_single_image img_size="large"][/vc_column][vc_column width="1/3"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" use_theme_fonts="yes" css=".vc_custom_1434542653233{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1434542828932{margin-bottom: 15px !important;}"]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][vc_single_image img_size="large"][/vc_column][/vc_row][vc_row][vc_column][vc_btn title="VIEW ALL" style="flat" color="success" size="lg" align="center" button_block="true"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Tabs with features */
$data = array();
$data['name'] = esc_html__( 'Tabs with features', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column][vc_tta_tabs spacing="" alignment="center" autoplay="5" active_section="1" no_fill_content_area="true"][vc_tta_section title="One" tab_id="1434542999695-a56fab9e-1f6710b4-996e"][vc_row_inner][vc_column_inner width="1/4"][/vc_column_inner][vc_column_inner width="1/4"][vc_single_image img_size="large"][/vc_column_inner][vc_column_inner width="1/4"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" use_theme_fonts="yes" css=".vc_custom_1434542653233{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1434542828932{margin-bottom: 15px !important;}"]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column_inner][vc_column_inner width="1/4"][/vc_column_inner][/vc_row_inner][/vc_tta_section][vc_tta_section title="Two" tab_id="1434542999696-c5f7d755-fafc10b4-996e"][vc_row_inner][vc_column_inner width="1/4"][/vc_column_inner][vc_column_inner width="1/4"][vc_single_image img_size="large"][/vc_column_inner][vc_column_inner width="1/4"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" use_theme_fonts="yes" css=".vc_custom_1434542653233{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1434542828932{margin-bottom: 15px !important;}"]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column_inner][vc_column_inner width="1/4"][/vc_column_inner][/vc_row_inner][/vc_tta_section][vc_tta_section title="Three" tab_id="1434543049270-c5988062-2c7810b4-996e"][vc_row_inner][vc_column_inner width="1/4"][/vc_column_inner][vc_column_inner width="1/4"][vc_single_image img_size="large"][/vc_column_inner][vc_column_inner width="1/4"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" use_theme_fonts="yes" css=".vc_custom_1434542653233{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1434542828932{margin-bottom: 15px !important;}"]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][/vc_column_inner][vc_column_inner width="1/4"][/vc_column_inner][/vc_row_inner][/vc_tta_section][/vc_tta_tabs][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Video section */
$data = array();
$data['name'] = esc_html__( 'Video section', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row" video_bg="yes" video_bg_parallax="content-moving" css=".vc_custom_1434537920178{padding-top: 150px !important;padding-bottom: 150px !important;}"][vc_column width="1/3"][/vc_column][vc_column width="1/3"][vc_custom_heading text="THIS IS CUSTOM HEADING ELEMENT" font_container="tag:h2|text_align:center|color:%23ffffff" use_theme_fonts="yes" css=".vc_custom_1434538077842{padding-bottom: 20px !important;}"][vc_separator color="white" border_width="2" el_width="50"][vc_column_text]

I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.

[/vc_column_text][vc_btn title="READ MORE" style="flat" color="purple" align="center"][/vc_column][vc_column width="1/3"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Video promo */
$data = array();
$data['name'] = esc_html__( 'Video promo', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row" full_height="yes" video_bg="yes" css=".vc_custom_1436534189440{margin-bottom: 0px !important;background-color: #319e60 !important;}"][vc_column width="1/2"][vc_empty_space height="300px"][vc_custom_heading text="CUSTOM HEADING FOR FULL HEIGHT HERO ROW" font_container="tag:h1|text_align:left|color:%23ffffff" use_theme_fonts="yes" css=".vc_custom_1436532193902{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1438783043420{padding-bottom: 35px !important;}"]This section looks good with color background, background image and even video background and can be used as a nice Hero type header for any type of site or introduction block because of full height row.[/vc_column_text][/vc_column][vc_column width="1/2"][/vc_column][/vc_row][vc_row full_width="stretch_row" full_height="yes" css=".vc_custom_1436534035043{background-color: #dd4944 !important;}"][vc_column width="1/6"][/vc_column][vc_column width="2/3"][vc_custom_heading text="PRODUCT OVERVIEW" font_container="tag:h2|text_align:center|color:%23ffffff" use_theme_fonts="yes" css=".vc_custom_1436534146913{margin-top: 0px !important;}"][vc_video][/vc_column][vc_column width="1/6"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Equal Feature List */
$data = array();
$data['name'] = esc_html__( 'Equal Feature List', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row" gap="35" equal_height="yes" css=".vc_custom_1456142754632{padding-top: 100px !important;padding-bottom: 100px !important;background-color: #eaeaea !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_column width="1/3" css=".vc_custom_1455714400431{background-color: #ffffff !important;border-radius: 5px !important;}"][vc_icon type="typicons" icon_typicons="typcn typcn-device-phone" color="white" background_style="rounded" background_color="vista_blue" size="lg" align="center"][vc_custom_heading font_container="tag:h3|text_align:center"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3" css=".vc_custom_1455714406281{background-color: #ffffff !important;border-radius: 5px !important;}"][vc_icon type="typicons" icon_typicons="typcn typcn-brush" color="white" background_style="rounded" background_color="orange" size="lg" align="center"][vc_custom_heading font_container="tag:h3|text_align:center"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3" css=".vc_custom_1455714413009{background-color: #ffffff !important;border-radius: 5px !important;}"][vc_icon type="typicons" icon_typicons="typcn typcn-flow-parallel" color="white" background_style="rounded" background_color="sandy_brown" size="lg" align="center"][vc_custom_heading font_container="tag:h3|text_align:center"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Parallax Introduction */
$data = array();
$data['name'] = esc_html__( 'Parallax Introduction', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row_content" full_height="yes" content_placement="middle" parallax="content-moving" css=".vc_custom_1456142923728{background-color: #eaeaea !important;}"][vc_column width="1/12"][/vc_column][vc_column width="1/12"][/vc_column][vc_column width="1/12"][/vc_column][vc_column width="1/2" css=".vc_custom_1449671939004{padding-right: 100px !important;padding-left: 100px !important;}"][vc_custom_heading font_container="tag:h1|text_align:center|color:%23ffffff"][vc_custom_heading font_container="tag:h3|text_align:center|color:%23ffffff"][vc_btn title="VIEW WORKS" style="outline" shape="square" color="white" align="center" css=".vc_custom_1456143020682{padding-top: 50px !important;}"][/vc_column][vc_column width="1/12"][/vc_column][vc_column width="1/12"][/vc_column][vc_column width="1/12"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Three Informative Blocks */
$data = array();
$data['name'] = esc_html__( 'Three Informative Blocks', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT

[vc_row gap="15" equal_height="yes" content_placement="top" css=".vc_custom_1456143366903{margin-top: 15px !important;}"][vc_column width="1/3" css=".vc_custom_1449585660682{padding-right: 35px !important;padding-left: 35px !important;background-color: #efefef !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_custom_heading text="Easy to Use Features ..." font_container="tag:h2|font_size:30|text_align:left" use_theme_fonts="yes"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read More" style="flat" shape="round" color="vista-blue"][/vc_column][vc_column width="1/3" css=".vc_custom_1456143219006{padding-right: 35px !important;padding-left: 35px !important;background-color: #efefef !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_custom_heading text="Discover Process Behind ..." font_container="tag:h2|font_size:30|text_align:left" use_theme_fonts="yes"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][vc_btn title="Read More" style="flat" shape="round" color="vista-blue"][/vc_column][vc_column width="1/3" css=".vc_custom_1449584499838{padding-right: 35px !important;padding-left: 35px !important;background-color: #40404a !important;}"][vc_custom_heading text="Additional Description Goes Here ..." font_container="tag:h3|text_align:center|color:%23ffffff" use_theme_fonts="yes"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Description Articles */
$data = array();
$data['name'] = esc_html__( 'Description Articles', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/3"][vc_custom_heading text="Why Build WordPress Site" font_container="tag:h1|font_size:44|text_align:left|color:%23444444|line_height:1" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css=".vc_custom_1453376297591{padding-top: 35px !important;}"]WordPress is the most popular platform around the globe for building high quality websites. And if you are not familiar with coding you can always find great tools like WPBakery Page Builder.[/vc_column_text][/vc_column][vc_column width="1/3"][vc_single_image img_size="full" css=".vc_custom_1456145319213{margin-top: 0px !important;}"][/vc_column][vc_column width="1/3"][/vc_column][/vc_row][vc_row css=".vc_custom_1453378670285{padding-bottom: 50px !important;}"][vc_column width="1/3" css=".vc_custom_1453378563701{border-top-width: 10px !important;border-right-width: 10px !important;border-bottom-width: 10px !important;border-left-width: 10px !important;border-left-color: #ea5d5d !important;border-left-style: solid !important;border-right-color: #ea5d5d !important;border-right-style: solid !important;border-top-color: #ea5d5d !important;border-top-style: solid !important;border-bottom-color: #ea5d5d !important;border-bottom-style: solid !important;}"][vc_single_image img_size="full" css=".vc_custom_1456145323378{margin-top: 0px !important;margin-right: -75px !important;padding-left: 50px !important;}"][/vc_column][vc_column width="1/3"][/vc_column][vc_column width="1/3"][vc_custom_heading text="Great Way To Show Your Works" font_container="tag:h1|font_size:44|text_align:left|color:%23444444|line_height:1" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css=".vc_custom_1453378348233{padding-top: 35px !important;}"]Discover brand new way to show your photos, videos and any other masterpiece. You have been relying on different website builder, but none of them offers such a great options as WordPress.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Full Height Features */
$data = array();
$data['name'] = esc_html__( 'Full Height Features', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row" full_height="yes" css=".vc_custom_1453212412853{margin-bottom: 0px !important;background-color: #6ab165 !important;}"][vc_column][vc_custom_heading text="When to Use Full Width and Video Background?" font_container="tag:h2|font_size:40|text_align:center|color:%23ffffff|line_height:1.5" google_fonts="font_family:Josefin%20Sans%3A100%2C100italic%2C300%2C300italic%2Cregular%2Citalic%2C600%2C600italic%2C700%2C700italic|font_style:600%20bold%20regular%3A600%3Anormal" css=".vc_custom_1453288229618{padding-bottom: 15px !important;}"][vc_separator color="custom" border_width="3" el_width="10" accent_color="#f4ca22"][vc_row_inner][vc_column_inner width="1/4"][vc_icon type="entypo" icon_entypo="entypo-icon entypo-icon-hourglass" color="white" background_style="rounded" background_color="chino" size="lg" align="center" css_animation="appear"][vc_custom_heading text="Landing Page" font_container="tag:h3|font_size:26|text_align:center|color:%23ffffff" google_fonts="font_family:Josefin%20Sans%3A100%2C100italic%2C300%2C300italic%2Cregular%2Citalic%2C600%2C600italic%2C700%2C700italic|font_style:600%20bold%20regular%3A600%3Anormal"][vc_column_text]Grab user attention on your landing pages with beautiful video background in combination with clear Call to Action sections.[/vc_column_text][/vc_column_inner][vc_column_inner width="1/4"][vc_icon type="entypo" icon_entypo="entypo-icon entypo-icon-graduation-cap" color="white" background_style="rounded" background_color="chino" size="lg" align="center" css_animation="appear"][vc_custom_heading text="Startup Website" font_container="tag:h3|font_size:26|text_align:center|color:%23ffffff" google_fonts="font_family:Josefin%20Sans%3A100%2C100italic%2C300%2C300italic%2Cregular%2Citalic%2C600%2C600italic%2C700%2C700italic|font_style:600%20bold%20regular%3A600%3Anormal"][vc_column_text]Innovative products requires modern and trendy sites. Full height rows and video background is exactly what you are looking for.[/vc_column_text][/vc_column_inner][vc_column_inner width="1/4"][vc_icon type="entypo" icon_entypo="entypo-icon entypo-icon-window" color="white" background_style="rounded" background_color="chino" size="lg" align="center" css_animation="appear"][vc_custom_heading text="Website Sections" font_container="tag:h3|font_size:26|text_align:center|color:%23ffffff" google_fonts="font_family:Josefin%20Sans%3A100%2C100italic%2C300%2C300italic%2Cregular%2Citalic%2C600%2C600italic%2C700%2C700italic|font_style:600%20bold%20regular%3A600%3Anormal"][vc_column_text]Combine different sections with and without video background, apply parallax to them, make them full width or full height for better content separation.[/vc_column_text][/vc_column_inner][vc_column_inner width="1/4"][vc_icon type="entypo" icon_entypo="entypo-icon entypo-icon-dot-3" color="white" background_style="rounded" background_color="chino" size="lg" align="center" css_animation="appear"][vc_custom_heading text="Minimalistic Design" font_container="tag:h3|font_size:26|text_align:center|color:%23ffffff" google_fonts="font_family:Josefin%20Sans%3A100%2C100italic%2C300%2C300italic%2Cregular%2Citalic%2C600%2C600italic%2C700%2C700italic|font_style:600%20bold%20regular%3A600%3Anormal"][vc_column_text]Give your site a space, use full height rows to represented only most important information at once and make sure user is focused only on the most important part.[/vc_column_text][/vc_column_inner][/vc_row_inner][vc_custom_heading text="and everywhere else you can imagine ..." font_container="tag:h4|font_size:24|text_align:center|color:%23ffffff|line_height:1.5" google_fonts="font_family:Josefin%20Sans%3A100%2C100italic%2C300%2C300italic%2Cregular%2Citalic%2C600%2C600italic%2C700%2C700italic|font_style:400%20italic%3A400%3Aitalic" css=".vc_custom_1453288268014{padding-bottom: 15px !important;}"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Business Description */
$data = array();
$data['name'] = esc_html__( 'Business Description', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row css=".vc_custom_1453217339571{padding-top: 50px !important;padding-bottom: 50px !important;}"][vc_column width="2/3"][vc_single_image img_size="full" alignment="center"][/vc_column][vc_column width="1/3"][vc_custom_heading text="Design Responsive Websites" font_container="tag:h2|font_size:36|text_align:left|color:%23515151|line_height:1.2" google_fonts="font_family:Istok%20Web%3Aregular%2Citalic%2C700%2C700italic|font_style:700%20bold%20regular%3A700%3Anormal"][vc_column_text]WPBakery Page Builder has everything you want to create portfolio pages or sections. Option rich grid elements that uses pages, posts, custom post types and Media LibraryÂ is a perfect choice for creating unique portfolios that sells.With just few clicks you can get your portfolio up and running - wether you are web designer, photographer or craftsmen. And it will all look good on mobile ...[/vc_column_text][vc_btn title="Read More" style="flat" color="juicy-pink" align="left" link="||"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Article Hero Image */
$data = array();
$data['name'] = esc_html__( 'Article Hero Image', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row_content_no_spaces" parallax="content-moving" css=".vc_custom_1456145516199{padding-top: 250px !important;padding-bottom: 250px !important;background-color: #eaeaea !important;}"][vc_column][/vc_column][/vc_row][vc_row css=".vc_custom_1453293187806{margin-top: -200px !important;background-color: #ffffff !important;}"][vc_column css=".vc_custom_1423574892319{background-color: #ffffff !important;}"][vc_custom_heading text="BOOST YOUR WordPress BLOG WITH PAGE BUILDER" font_container="tag:h2|font_size:46|text_align:left|color:%233a3a3a|line_height:1" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:700%20bold%20regular%3A700%3Anormal" css=".vc_custom_1453293169333{margin-top: 0px !important;padding-right: 200px !important;padding-bottom: 35px !important;}"][vc_column_text css=".vc_custom_1437055718275{margin-bottom: 20px !important;}"]Managing blog can sometimes be hard, remember how you deal with formatting or if you wish to add some simple feature like image, video, button or separator. There is no doubt that WordPress is best solution for blog, but dealing with shortcodes is time consuming process you could easily avoid.Start building your blog pages and posts visually. With WPBakery Page Builder you can instantly see changes and adapt to them by using Frontend editor or you can switch to Backend editor if you think that you have too much content and schematic view fits you better. It really does not matter are you highly talented technician or a small business owner - managing your blog with WPBakery Page Builder will save your time.[/vc_column_text][vc_btn title="READ MORE" style="outline" shape="square" color="black" align="left" link="||" el_class="get_my_copy"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** EMy Team Members */
$data = array();
$data['name'] = esc_html__( 'My Team Members', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column][vc_custom_heading text="Why Business Choose WPBakery Page Builder?" font_container="tag:h3|font_size:38|text_align:center|color:%233a3a3a|line_height:1.2" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal" css=".vc_custom_1453298979959{padding-bottom: 35px !important;}"][/vc_column][/vc_row][vc_row gap="15" equal_height="yes" css=".vc_custom_1453299367133{padding-bottom: 50px !important;}"][vc_column width="1/4"][vc_single_image img_size="200x200" alignment="center" style="vc_box_circle" css_animation="top-to-bottom"][vc_custom_heading text="Paula O'Reilly" font_container="tag:h4|font_size:22|text_align:center|color:%233a3a3a|line_height:1.2" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css=".vc_custom_1437056586937{margin-bottom: 10px !important;}"]Medium Size Business Owner[/vc_column_text][vc_column_text]My client loves how easy it is for them to manage their own site, after I set it up using WPBakery Page Builder page builder plugin for WordPress.[/vc_column_text][vc_btn title="Get in Touch" style="flat" shape="round" color="primary" align="center" link="||"][/vc_column][vc_column width="1/4"][vc_single_image img_size="200x200" alignment="center" style="vc_box_circle" css_animation="top-to-bottom"][vc_custom_heading text="Anabella Thomson" font_container="tag:h4|font_size:22|text_align:center|color:%233a3a3a|line_height:1.2" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css=".vc_custom_1437056567677{margin-bottom: 10px !important;}"]Startup Business Owner[/vc_column_text][vc_column_text]This plug-in was/is one of the BEST investments Iâ€™ve ever made. One thing is certain. Code Canyon/WPBakery is on top of this gem.[/vc_column_text][vc_btn title="Get in Touch" style="flat" shape="round" color="primary" align="center" link="||"][/vc_column][vc_column width="1/4"][vc_single_image img_size="200x200" alignment="center" style="vc_box_circle" css_animation="top-to-bottom"][vc_custom_heading text="Martin von Berdich" font_container="tag:h4|font_size:22|text_align:center|color:%233a3a3a|line_height:1.2" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css=".vc_custom_1437056604397{margin-bottom: 10px !important;}"]Client Relationship Manager[/vc_column_text][vc_column_text]WPBakery Page Builder is our number one requirement because of WPBakery Page Builder, our clients can manage their own website[/vc_column_text][vc_btn title="Get in Touch" style="flat" shape="round" color="primary" align="center" link="||"][/vc_column][vc_column width="1/4"][vc_single_image img_size="200x200" alignment="center" style="vc_box_circle" css_animation="top-to-bottom"][vc_custom_heading text="Paula Smith" font_container="tag:h4|font_size:22|text_align:center|color:%233a3a3a|line_height:1.2" google_fonts="font_family:Montserrat%3Aregular%2C700|font_style:400%20regular%3A400%3Anormal"][vc_column_text css=".vc_custom_1437056630846{margin-bottom: 10px !important;}"]Small Business Owner[/vc_column_text][vc_column_text]In my opinion this is the greatest advance of WordPress since itâ€™s creation and is the most outstanding plugin on the market.[/vc_column_text][vc_btn title="Get in Touch" style="flat" shape="round" color="primary" align="center" link="||"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Hero Image With Description */
$data = array();
$data['name'] = esc_html__( 'Hero Image With Description', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row" css=".vc_custom_1456147693944{padding-top: 100px !important;padding-bottom: 100px !important;background-color: #eaeaea !important;}"][vc_column width="1/3"][/vc_column][vc_column width="1/3" css=".vc_custom_1456147681162{background-color: #ffffff !important;border: 5px solid #353535 !important;}"][vc_custom_heading font_container="tag:h3|text_align:center|color:%23353535"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column][vc_column width="1/3"][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Description with Image on Background */
$data = array();
$data['name'] = esc_html__( 'Description with Image on Background', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row full_width="stretch_row" css=".vc_custom_1456147865877{padding-top: 100px !important;padding-bottom: 100px !important;background-color: #eaeaea !important;}"][vc_column][vc_row_inner equal_height="yes" css=".vc_custom_1456148051953{margin-top: 0px !important;}"][vc_column_inner width="1/2" css=".vc_custom_1456148038655{background-color: #dd4949 !important;}"][vc_single_image img_size="full"][/vc_column_inner][vc_column_inner width="1/2" css=".vc_custom_1456148028687{padding-right: 35px !important;padding-left: 35px !important;background-color: #dd4949 !important;}"][vc_custom_heading font_container="tag:h2|text_align:left|color:%23ffffff"][vc_column_text]I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );

/** Three Image with Article */
$data = array();
$data['name'] = esc_html__( 'Three Image with Article', 'js_composer' );
$data['disabled'] = true;
$data['content'] = <<<CONTENT
[vc_row][vc_column width="1/3"][vc_single_image img_size="full"][/vc_column][vc_column width="1/3"][vc_single_image img_size="full"][/vc_column][vc_column width="1/3"][vc_single_image img_size="full"][/vc_column][/vc_row][vc_row][vc_column width="1/2"][vc_custom_heading font_container="tag:h5|text_align:left" use_theme_fonts="yes" css=".vc_custom_1456150396297{margin-top: 0px !important;}"][vc_custom_heading use_theme_fonts="yes" css=".vc_custom_1456150386744{margin-top: 0px !important;}"][vc_column_text css=".vc_custom_1456150379129{padding-top: 15px !important;}"]Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque id condimentum felis. Duis sed ex et magna porttitor hendrerit. Nulla et lacinia ipsum. Morbi tincidunt eros ac luctus efficitur. Suspendisse potenti. Duis bibendum gravida nisi et varius.[/vc_column_text][vc_btn title="Read More" style="flat" shape="round" color="chino"][/vc_column][vc_column width="1/2"][vc_column_text]Aliquam erat volutpat. Morbi auctor malesuada vehicula. Pellentesque sed mi accumsan, facilisis purus quis, viverra ligula. Phasellus tellus tellus, efficitur vel lobortis eget, feugiat at eros. Donec id nunc nec erat vestibulum viverra et a ipsum. Aenean eros eros, venenatis pretium nibh non, ornare vehicula mauris. Curabitur vel dui quis est efficitur pharetra et eu elit. Sed efficitur porta ex laoreet lobortis. Donec id gravida mi, eu vehicula quam. Cras tristique volutpat diam, in dignissim orci tristique ut. Duis in enim non massa ullamcorper elementum. Donec metus leo, tempor ac volutpat sed, laoreet quis arcu. Nullam in enim at est cursus ultrices efficitur vitae justo.[/vc_column_text][/vc_column][/vc_row]
CONTENT;

vc_add_default_templates( $data );
